Hi Andreas,

* Andreas Bauer <baue...@gmail.com> [2016-03-25 19:20 +0100]:

> Hi Elimar,
> 
> thanks again for letting me know about this issue and building the
> patch.  I too have tested the latest patch for a few weeks and just
> made a release of it, as it seems to do the trick:
> 
>   https://sourceforge.net/projects/mailfilter/files/Mailfilter/0.8.4/
> 
> I hope that as such, this package can remain in Debian.  Would be much
> obliged to get a quick confirmation of this, or further instructions
> on how I may be able to help in this regard.

mailfilter 0.8.4.1-1 has entered Debian unstable today. Our package
checker "lintian" found some spell errors which I patched into the
package. Please find the patches attached.

Thanks for your contribution
Elimar
-- 
  Alles was viel bedacht wird ist bedenklich!;-)
         Friedrich Nietzsche
Author: Elimar Riesebieter <riese...@lxtec.de>
Subject: Fix spellerror in mailfilterex.5 
Forwarded: yes
Last-Update: 2016-03-28

diff -Naurd a/man/mailfilterex.5 b/man/mailfilterex.5
--- a/man/mailfilterex.5	2014-05-11 17:24:35.000000000 +0200
+++ b/man/mailfilterex.5	2016-03-28 13:42:18.030238819 +0200
@@ -214,7 +214,7 @@
 errors and the like.  Examples in this man page all use extended type.
 .SH "NOTES"
 If you are new to Regular Expressions and new to Mailfilter, you might want to
-experiment a bit, before you accidently delete messages for real. For such
+experiment a bit, before you accidentally delete messages for real. For such
 cases Mailfilter provides two keywords. TEST can be used to only simulate the
 deletion of messages and SHOW_HEADERS stores all the e-mail headers that get
 examined by the program.
Author: Elimar Riesebieter <riese...@lxtec.de>
Subject: Fix spellerror for occured in several files
Forwarded: yes
Last-Update: 2016-03-28

diff -Naurd a/src/header.cc b/src/header.cc
--- a/src/header.cc	2014-05-11 17:16:44.000000000 +0200
+++ b/src/header.cc	2016-03-28 13:57:57.307154131 +0200
@@ -130,7 +130,7 @@
 	}
       catch (const exception& r_err)
 	{
-	  ERROR_MSG("Runtime exception occured while parsing rcfile: "
+	  ERROR_MSG("Runtime exception occurred while parsing rcfile: "
 		    + (string)r_err.what ());
 	  exit (-1);
 	}
diff -Naurd a/src/mailfilter.cc b/src/mailfilter.cc
--- a/src/mailfilter.cc	2014-05-11 17:16:44.000000000 +0200
+++ b/src/mailfilter.cc	2016-03-28 13:57:12.452489891 +0200
@@ -111,7 +111,7 @@
     }
   catch (const exception& r_err)
     {
-      ERROR_MSG("Runtime exception occured: "
+      ERROR_MSG("Runtime exception occurred: "
 		+ (string)r_err.what ());
       return -1;
     }
@@ -183,7 +183,7 @@
     }
   catch (const exception& r_err)
     {
-      logger->print_err ("Runtime exception occured: "
+      logger->print_err ("Runtime exception occurred: "
 			+ (string)r_err.what ());
       return -1;
     }
diff -Naurd a/src/pop3.cc b/src/pop3.cc
--- a/src/pop3.cc	2016-02-29 15:45:10.000000000 +0100
+++ b/src/pop3.cc	2016-03-28 13:58:44.585691415 +0200
@@ -61,14 +61,14 @@
   // Send user name and read server reply.
   if (conn->c_write (usr_name.c_str ()) == -1 || !REPLY_OK)
     {
-      logger->print_err("Error occured while sending username to server.");
+      logger->print_err("Error occurred while sending username to server.");
       return false;
     }
 
   // Send password and read server reply.
   if (conn->c_write (pass_wd.c_str ()) == -1 || !REPLY_OK)
     {
-      logger->print_err("Error occured while sending password to server.");
+      logger->print_err("Error occurred while sending password to server.");
       return false;
     }
 
@@ -97,7 +97,7 @@
 // The function scans the headers inside a POP3 account for spam.  It
 // will delete all spam messages in the account and return 0 when all
 // the hard work is done.  A negative integer is returned if an error
-// occured.
+// occurred.
 
 int POP3 :: scan (void) const
 {
@@ -111,7 +111,7 @@
   // Determine number of messages waiting to be examined.
   if ((num_messages = status ()) < 0)
     {
-      logger->print_err ("Error occured while sending STAT to server.");
+      logger->print_err ("Error occurred while sending STAT to server.");
       return GEN_FAILURE_FLAG;
     }
   
@@ -130,7 +130,7 @@
 	  cmd = "LIST " + msg_no.str () + "\r\n";
 	  if (conn->c_write (cmd.c_str ()) == -1 || !REPLY_OK)
 	    {
-	      logger->print_err ("Error occured while sending LIST to server.");
+	      logger->print_err ("Error occurred while sending LIST to server.");
 	      return GEN_FAILURE_FLAG;
 	    }
 	  
@@ -143,7 +143,7 @@
 	  cmd = "TOP " + msg_no.str () + " 0\r\n";
 	  if (conn->c_write (cmd.c_str ()) == -1 || !HEADER_OK)
 	    {
-	      logger->print_err ("Error occured while sending TOP to server.");
+	      logger->print_err ("Error occurred while sending TOP to server.");
 	      return GEN_FAILURE_FLAG;
 	    }
 
diff -Naurd a/src/socket.cc b/src/socket.cc
--- a/src/socket.cc	2016-03-28 13:53:31.000000000 +0200
+++ b/src/socket.cc	2016-03-28 13:57:36.958213872 +0200
@@ -183,7 +183,7 @@
     }
   else
     {
-      logger->print_err ("Timeout occured.");
+      logger->print_err ("Timeout occurred.");
       return GEN_FAILURE_FLAG;
     }
 
@@ -292,7 +292,7 @@
   // Only read if the socket is ready and able to send data.
   error = select (sd + 1, &rfds, NULL, NULL, &tv);
   
   // An error occured while trying to poll server.  We did not get a
   // file descriptor.
   if (error < 0)
     {
@@ -292,7 +292,7 @@
   error = select (sd + 1, &rfds, NULL, NULL, &tv);
   
-  // An error occured while trying to poll server.  We did not get a
+  // An error occurred while trying to poll server.  We did not get a
   // file descriptor.
   if (error < 0)

Attachment: signature.asc
Description: PGP signature

Reply via email to